@@ -10,6 +10,9 @@ from .exceptions import SellingApiForbiddenException
 from .exceptions import SellingApiRequestThrottledException
 from .exceptions import SellingApiServerException
 from .exceptions import SellingApiTemporarilyUnavailableException
+from .exceptions import SellingApiTooLargeException
+from .exceptions import SellingApiStateConflictException
+from .exceptions import SellingApiUnsupportedFormatException
 from .schedules import Schedules
 from .report_status import ReportStatus
 from .sales_enum import FirstDayOfWeek, Granularity, BuyerType
@@ -20,6 +23,7 @@ from .credential_provider import CredentialProvider, MissingCredentials
 from .ApiResponse import ApiResponse
 from .processing_status import ProcessingStatus
 from .reportTypes import ReportType
+from .feedTypes import FeedType
 from sp_api.auth import AccessTokenClient, Credentials
 from sp_api.auth.exceptions import AuthorizationError
 from sp_api.base.inegibility_reasons import IneligibilityReasonList
@@ -29,6 +33,7 @@ __all__ = [
     'AuthorizationError',
     'AccessTokenClient',
     'ReportType',
+    'FeedType',
     'ProcessingStatus',
     'ApiResponse',
     'Client',
@@ -40,10 +45,14 @@ __all__ = [
     'SellingApiException',
     'SellingApiBadRequestException',
     'SellingApiNotFoundException',
+    'SellingApiServerException',
     'SellingApiForbiddenException',
     'SellingApiBadRequestException',
     'SellingApiRequestThrottledException',
     'SellingApiTemporarilyUnavailableException',
+    'SellingApiTooLargeException',
+    'SellingApiStateConflictException',
+    'SellingApiUnsupportedFormatException',
     'Schedules',
     'ReportStatus',
     'FirstDayOfWeek',
